!{\src2tex{textfont=tt}}
!!****f* ABINIT/calc_hatden
!! NAME 
!! calc_hatden
!!
!! FUNCTION
!! Compute the compensation charge density;
!! Compute also Qij_hat terms for i,j=(0,0).
!!
!! COPYRIGHT
!! Copyright (C) 1998-2004 ABINIT group (FJ, MT)
!! This file is distributed under the terms of the 
!! GNU General Public License, see ~ABINIT/Infos/copyright
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~ABINIT/Infos/contributors .
!!
!! INPUTS
!!  pawarray
!!    %gnorm(l_size)= Normalisation of qijl for each l
!!    %shapefunc(mesh_size)= Normalized shape function
!!    %tvaleden4pr2(bigmesh_size) = Density 4*pi*r^2*tn1,
!!                                  coming from the code Atompaw 
!!    %valeden4pr2(bigmesh_size) = Density 4*pi*r^2*n1,
!!                                 coming from the code Atompaw 
!!  pawdata
!!    %rad(bigmesh_size)= Coordinates of the radial grid
!!  pshead
!!    %mesh_size= Dimension of radial mesh for phi, tphi ...
!!    %rad_step= Step corresponding to radial mesh
!!
!! OUTPUT
!!  pawarray
!!    %hatden4pr2(mesh_size)= Compensation charge density
!!    %q00hat(mesh_size)= Qij_hat terms with i,j=(0,0)
!!
!! PARENTS
!!      atompaw2abinit
!! CHILDREN
!!
!! SOURCE

 subroutine calc_hatden(pawarray,pawdata,pshead)

 use defs_basis
 use defs_pawps

 implicit none

!Arguments ------------------------------------
!These types are defined in defs_pawps
 type(pawarray_type) :: pawarray
 type(pawdata_type)  :: pawdata
 type(pshead_type)   :: pshead

!Local variables-------------------------------
 integer :: ir
 real(dp) :: intg_diff
 real(dp), allocatable :: diff(:)

! *************************************************************************

!Compute int[4*pi*r^2(n1(r)-tn1(r))dr]
!------------------------------------------------------------------
 allocate(diff(pshead%mesh_size))
 do ir=1,pshead%mesh_size
  diff(ir)=(pawarray%valeden4pr2(ir)-pawarray%tvaleden4pr2(ir))
 enddo
 call ctrap(pshead%mesh_size,diff,pshead%rad_step,intg_diff)
 deallocate(diff)

!Compute hat density
!------------------------------------------------------------------
 do ir=1,pshead%mesh_size
  pawarray%q00hat(ir)=pawarray%gnorm(1)*pawarray%shapefunc(ir)&
&                                      *pawdata%rad(ir)**2
  pawarray%hatden4pr2(ir)= pawarray%q00hat(ir)*intg_diff
 enddo

end subroutine
!!***

