!{\src2tex{textfont=tt}}
!!****f* ABINIT/calc_shapef
!! NAME 
!! calc_shapef
!!
!! FUNCTION
!! Compute normalized shape function and its moments (gnorm)
!!
!! COPYRIGHT
!! Copyright (C) 1998-2004 ABINIT group (FJ, MT)
!! This file is distributed under the terms of the 
!! GNU General Public License, see ~ABINIT/Infos/copyright
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~ABINIT/Infos/contributors .
!!
!! INPUTS
!!  pawdata
!!    %rad(bigmesh_size)= Coordinates of the radial grid
!!  pshead
!!    %lambda= Lambda in gaussian type g(r)
!!    %l_size= Max. value of l+1 leading to a non zero Gaunt coeffs
!!    %mesh_size= Dimension of radial mesh for phi, tphi ...
!!    %rad_step= Step corresponding to radial mesh
!!    %rc_sph= Default PAW sphere radius
!!    %shape_type= Shape function type
!!    %sigma= Sigma for gaussian type g(r)
!!
!! OUTPUT
!!  pawarray
!!    %gnorm(l_size)= Normalisation of qijl for each l
!!    %shapefunc(mesh_size)= Normalized shape function
!!
!! PARENTS
!!      atompaw2abinit
!!
!! CHILDREN
!!      ctrap
!!
!! SOURCE

 subroutine calc_shapef(pawarray,pawdata,pshead)

 use defs_basis
 use defs_pawps

 implicit none

!Arguments ------------------------------------	
!These types are defined in defs_pawps
 type(pawarray_type) :: pawarray
 type(pawdata_type)  :: pawdata
 type(pshead_type)   :: pshead

!Local variables-------------------------------
 integer :: il,ir
 real(dp) :: arg,intg,shapefunc1,shapefunc2
 real(dp), allocatable :: ff(:)

!Statement functions -----------------------------------
 shapefunc1(arg)= exp(-(arg/pshead%sigma)**pshead%lambda)
 shapefunc2(arg)= (sin(pi*arg/pshead%rc_sph)/(pi*arg/pshead%rc_sph))**2

! *************************************************************************

!Select the suitable shape function
 pawarray%shapefunc(1)=1.d0
 if (pshead%shape_type==1) then
  do ir=2,pshead%mesh_size
   pawarray%shapefunc(ir)=shapefunc1(pawdata%rad(ir))
  enddo
 else if (pshead%shape_type==2) then
  do ir=2,pshead%mesh_size
   pawarray%shapefunc(ir)=shapefunc2(pawdata%rad(ir))
  enddo
 else
  print *,"Error in calc_shapef: invalid value of pshead%shape_type !"
  stop
 endif

!Compute Gnorm
 allocate(ff(pshead%mesh_size))
 pawarray%gnorm(:)=zero
 do il=1,pshead%l_size
  ff(1)=zero
  ff(2:pshead%mesh_size)=pawarray%shapefunc(2:pshead%mesh_size)&
                        *pawdata%rad(2:pshead%mesh_size)**(2*il)
  call ctrap(pshead%mesh_size,ff,pshead%rad_step,intg)
  pawarray%gnorm(il)=1.d0/intg
 enddo
 deallocate(ff)

end subroutine
!!***
