!{\src2tex{textfont=tt}}
!!****f* ABINIT/calc_tcore
!! NAME 
!! calc_tcore
!!
!! FUNCTION
!! Calculate pseudized core densisty (tcoredens)
!!           from core density (coredens)
!!
!! COPYRIGHT
!! Copyright (C) 1998-2004 ABINIT group (FJ, MT)
!! This file is distributed under the terms of the 
!! GNU General Public License, see ~ABINIT/Infos/copyright
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~ABINIT/Infos/contributors .
!!
!! INPUTS
!!  pawarray
!!    %coreden4pr2(bigmesh_size)= Core density multiplied by 4Pi.r2
!!  pawdata
!!    %rad(bigmesh_size)= Coordinates of the radial grid
!!  pshead
!!    %bigmesh_size= Dimension of radial mesh for read coredens/valedens
!!    %core_meshsz= Dimension of radial mesh for (t)coredens for coredens<pgiven prec
!!    %mesh_size= Dimension of radial mesh for phi, tphi ...
!!    %rad_step= Step corresponding to radial mesh
!!    %rc_sph= Default PAW sphere radius
!!
!! OUTPUT
!!  pawarray
!!    %tcoreden4pr2(bigmesh_size)= Pseudized core density multiplied by 4Pi.r2
!!  pawps
!!    %coredens(mesh_size)= Core density of the atom
!!    %tcoredens(mesh_size)= Pseudo-core density of the atom
!!
!! PARENTS
!!      atompaw2abinit
!!
!! CHILDREN
!!      calc_psden
!!
!! SOURCE

 subroutine calc_tcore(pawarray,pawdata,pawps,pshead)

 use defs_basis
 use defs_pawps

 implicit none

!Arguments ------------------------------------
!These types are defined in defs_pawps
 type(pawarray_type) :: pawarray
 type(pawdata_type)  :: pawdata
 type(pawps_type)    :: pawps
 type(pshead_type)   :: pshead

!Local variables-------------------------------
 real(dp) :: core_prec=1.d-8
 integer :: ir,isize
 real(dp) :: yp1,yp2,yp3

! *************************************************************************

!First, translate coredens
 do ir=2,pshead%bigmesh_size
  pawps%coredens(ir) = pawarray%coreden4pr2(ir)&
&                    / (four_pi*pawdata%rad(ir)**2)
 enddo

!Deduce coredens at r=0
 yp2=(pawps%coredens(3)-pawps%coredens(2))/(pawdata%rad(3)-pawdata%rad(2))
 yp3=(pawps%coredens(4)-pawps%coredens(3))/(pawdata%rad(4)-pawdata%rad(3))
 yp1=yp2+(yp2-yp3)*(pawdata%rad(2)-pawdata%rad(1))/(pawdata%rad(3)-pawdata%rad(2))
 pawps%coredens(1)=pawps%coredens(2)-(yp1+yp2)*pawdata%rad(2)

!Then, compute pseudized density tcoredens
 call calc_psden(pawps%tcoredens,pshead%mesh_size,pawps%coredens,&
&                pshead%rc_sph,pshead%rad_step)
 do ir=1+pshead%mesh_size,pshead%bigmesh_size
  pawps%tcoredens(ir) = pawps%coredens(ir)
 enddo

!And translate pseudized density
 do ir=1,pshead%mesh_size
  pawarray%tcoreden4pr2(ir) = pawps%tcoredens(ir)&
&                           * (four_pi*pawdata%rad(ir)**2)
 enddo
 do ir=1+pshead%mesh_size,pshead%bigmesh_size
  pawarray%tcoreden4pr2(ir) = pawarray%coreden4pr2(ir)
 enddo

print *,"ici"
!Adjust mesh size for (t)core density in order to get it lower than given precision
 isize=pshead%mesh_size
 do ir=pshead%mesh_size,pshead%bigmesh_size
  if (abs(pawps%coredens(ir))>core_prec) isize=ir
 enddo
print *,"ici"
 pshead%core_meshsz=max(isize,pshead%mesh_size)
print *,"ici"
 if (pshead%core_meshsz>pshead%mesh_size) then
  write(6,'(/,a)') 'Info:'
  write(6,'(a,i4,/,a,g9.2,a)') &
&   '  Mesh size for core density has been adjusted to ',pshead%core_meshsz,&
&   '  in order to get it lower than given precision (',core_prec,').'
 endif

end subroutine
!!***
