!{\src2tex{textfont=tt}}
!!****f* ABINIT/poisson
!! NAME
!! poisson
!! 
!! FUNCTION
!! Use Numerov algorithm to solve poisson equation
!!
!! COPYRIGHT
!! Copyright (C) 1998-2004 ABINIT group (GJ, FJ, NH)
!! This file is distributed under the terms of the 
!! GNU General Public License, see ~ABINIT/Infos/copyright
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~ABINIT/Infos/contributors .
!! 
!! INPUTS 
!!  den(nn) is electron density * (4*pi*r**2)
!!  hh= step for integration
!!  nn= dimension of the radial arrays
!!  qq is the total electron charge
!! 
!! OUTPUT
!!  rv(nn) is returned as electrostatic potential * r (in Hartree*Bohr!)
!!
!! NOTES
!!  Comes from the routines poisson of the code atompaw by N. Holzwarth
!!  Warning: first radius r(1) must be equal to radial step h (not zero) !
!!
!! PARENTS
!!      calc_vhnzc,calc_vhtnzc
!!
!! CHILDREN
!!
!! SOURCE

 subroutine poisson(den,hh,nn,qq,rv)

  use defs_basis
  implicit none

!Arguments ------------------------------------
 integer :: nn
 real (dp) :: hh,qq
 real (dp) :: den(nn),rv(nn)
      
!Local variables-------------------------------
 integer :: ii
 real (dp) :: sd,sl,ss2 
 real (dp) :: aa(nn),bb(nn)

! *************************************************************************

 sd=2.d0
 sl=-1.d0
 do ii=1,nn
  aa(ii)=hh*den(ii)/(12.d0*ii)
 enddo
 rv(1)=10*aa(1)+aa(2)
 do ii=2,nn-1
  rv(ii)=10*aa(ii)+aa(ii+1)+aa(ii-1)
 enddo
 rv(nn)=10*aa(nn)+aa(nn-1)+qq

! Use Thomas s algorithm for inverting matrix
! Dale U. von Rosenberg, Methods for the Numerical Solution of
! Partial Differential Equations, Am. Elsevier Pub., 1969, pg. 113
 aa(1)=sd
 ss2=sl*sl
 do ii=2,nn
  aa(ii)=sd-ss2/aa(ii-1)
 enddo
 bb(1)=rv(1)/sd
 do ii=2,nn
  bb(ii)=(rv(ii)-sl*bb(ii-1))/aa(ii)
 enddo
 rv(nn)=bb(nn)
 do ii=nn-1,1,-1
  rv(ii)=bb(ii)-sl*rv(ii+1)/aa(ii)
 enddo

 end subroutine
!!***
