!{\src2tex{textfont=tt}}
!!****f* ABINIT/poisson2
!! NAME
!! poisson2
!! 
!! FUNCTION
!! Solve poisson equation by direct integration
!!
!! COPYRIGHT
!! Copyright (C) 1998-2004 ABINIT group (GJ, FJ, NH)
!! This file is distributed under the terms of the 
!! GNU General Public License, see ~ABINIT/Infos/copyright
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~ABINIT/Infos/contributors .
!! 
!! INPUTS 
!!  den(nn) is electron density * (4*pi*r**2) from r=0 to r=inf
!!  hh= step for integration
!!  nn= dimension of the radial arrays (from r=0 to r=inf)
!! 
!! OUTPUT
!!  rv(nn) is returned as electrostatic potential * r in Hartree
!!
!! PARENTS
!!
!! CHILDREN
!!
!! SOURCE

 subroutine poisson2(den,hh,nn,rv)

  use defs_basis

  implicit none

!Arguments ------------------------------------
 integer :: nn
 real (dp) :: hh
 real (dp) :: den(nn),rv(nn)
      
!Local variables-------------------------------
 integer :: ir,jr
 real(dp) :: endpt,ssum
 real(dp), allocatable :: den_overr(:),intg_den(:),intg_den_overr(:)

! *********************************************************************

 allocate (den_overr(nn),intg_den(nn),intg_den_overr(nn))

!Compute den(r)/r
!-------------------------------------------
 den_overr(1)=zero
 do ir=2,nn
  den_overr(ir)= den(ir)/(dble(ir-1)*hh)
 enddo

!Compute Intg_{0,r} [den(x).dx]
!    and Intg_{0,r} [den(x)/x.dx] for each r
!-------------------------------------------
!        Inspired by routine ctrap from Abinit...

 intg_den(1)=zero;intg_den_overr(1)=zero

 do ir=2,nn

  if (ir<10) then
   intg_den(ir)=intg_den(ir-1)&
               +(den(ir)+den(ir-1))*hh/2.d0
   intg_den_overr(ir)=intg_den_overr(ir-1)&
               +(den_overr(ir)+den_overr(ir-1))*hh/2.d0
  else if (ir==10) then
  intg_den(ir)=(23.75d0*(den(1)+den(10))&
&             + 95.10d0*(den(2)+den(9)) &
&             + 55.20d0*(den(3)+den(8)) &
&             + 79.30d0*(den(4)+den(7)) &
&             + 70.65d0*(den(5)+den(6)))*hh/ 72.d0
  intg_den_overr(ir)=(23.75d0*(den_overr(1)+den_overr(10))&
&             + 95.10d0*(den_overr(2)+den_overr(9)) &
&             + 55.20d0*(den_overr(3)+den_overr(8)) &
&             + 79.30d0*(den_overr(4)+den_overr(7)) &
&             + 70.65d0*(den_overr(5)+den_overr(6)))*hh/ 72.d0
  else
   intg_den(ir)=intg_den(ir-1)+    &
&               (23.75d0*den(ir  ) &
&              + 71.35d0*den(ir-1) &
&              - 39.90d0*den(ir-2) &
&              + 24.10d0*den(ir-3) &
&              - 08.65d0*den(ir-4) &
&              + 01.35d0*den(ir-5))*hh/ 72.d0
   intg_den_overr(ir)=intg_den_overr(ir-1)+    &
&               (23.75d0*den_overr(ir  ) &
&              + 71.35d0*den_overr(ir-1) &
&              - 39.90d0*den_overr(ir-2) &
&              + 24.10d0*den_overr(ir-3) &
&              - 08.65d0*den_overr(ir-4) &
&              + 01.35d0*den_overr(ir-5))*hh/ 72.d0
  endif

 enddo

!r* v(r) = { Intg_{0,r} [den(x).dx] + r *
!  (Intg_{0,inf} [den(x)/x.dx]-Intg_{0,r} [den(x)/x.dx]) }
!-------------------------------------------
 do ir=1,nn
  rv(ir)=intg_den(ir)+dble(ir-1)*hh &
&       *(intg_den_overr(nn)-intg_den_overr(ir))
 enddo

 deallocate(den_overr,intg_den,intg_den_overr)

 end subroutine
!!***
