!{\src2tex{textfont=tt}}
!!****f* ABINIT/realgaunt
!! NAME
!! realgaunt
!!
!! FUNCTION
!! This routine compute "real gaunt coefficients", i.e. gaunt
!! coefficients according to "real spherical harmonics"
!!
!! COPYRIGHT
!! Copyright (C) 1998-2004 ABINIT group (MT, FJ)
!! This file is distributed under the terms of the 
!! GNU General Public License, see ~ABINIT/Infos/copyright
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~ABINIT/Infos/contributors .
!!
!! INPUTS
!!   li,mi,lj,mj,ll,mm= six quantum numbers defining the Gaunt coef.
!!   l_size=maximum value for ll
!!
!! OUTPUT
!!   realgaunt(li,mi,lj,mj,ll,mm,l_size)=the "real" gaunt coefficient
!!
!! PARENTS
!!   calc_qijl
!!
!! CHILDREN
!!      gaunt
!!
!! SOURCE

 function realgaunt(li,mi,lj,mj,ll,mm,l_size)

 use defs_basis
 
 implicit none
 
!Arguments ---------------------------------------------
 integer :: l_size,li,lj,ll,mi,mj,mm
 real(dp) :: realgaunt
 
!Local variables ---------------------------------------
 integer :: ilang,mlang,mlang1,mlang2,mlang3
 real(dp) :: c11,c12,c21,c22,c31,c32,fact,gaunt
 type coeff_type
! Gives the matrix cc: Sl=cc*Yl
 real(dp),pointer :: cc(:,:,:)
 end type coeff_type
 type(coeff_type) :: coeff(2*l_size-1)
 
! *********************************************************************

 realgaunt=zero

 if(ll > l_size-1) return

 do ilang=1,l_size
  allocate (coeff(ilang)%cc(2,2*ilang-1,2*ilang-1))
  coeff(ilang)%cc(:,:,:)=zero
  coeff(ilang)%cc(1,ilang,ilang)=one
  do mlang=1,ilang-1
   coeff(ilang)%cc(1,ilang+mlang,ilang+mlang)=(-1.d0)**mlang/sqrt(2.d0)
   coeff(ilang)%cc(1,ilang-mlang,ilang+mlang)=1.d0/sqrt(2.d0)
   coeff(ilang)%cc(2,ilang+mlang,ilang-mlang)=-(-1.d0)**mlang/sqrt(2.d0)
   coeff(ilang)%cc(2,ilang-mlang,ilang-mlang)=1.d0/sqrt(2.d0)
  enddo
 enddo

 do mlang1=-li,li
  c11=coeff(li+1)%cc(1,li+mlang1+1,li+mi+1)
  c12=coeff(li+1)%cc(2,li+mlang1+1,li+mi+1)
  do mlang2= -lj,lj
   c21=coeff(lj+1)%cc(1,lj+mlang2+1,lj+mj+1)
   c22=coeff(lj+1)%cc(2,lj+mlang2+1,lj+mj+1)
   do mlang3= -ll,ll
    c31=coeff(ll+1)%cc(1,ll+mlang3+1,ll+mm+1)
    c32=coeff(ll+1)%cc(2,ll+mlang3+1,ll+mm+1)

    fact=c11*c21*c31  -  c12*c22*c31&
&       -c11*c22*c32  -  c12*c21*c32
    if((abs(fact)>=tol12).and.(mlang3==-mlang2-mlang1)) then
     realgaunt=realgaunt+fact*(-1)**mlang2&
&             *gaunt(ll,mlang3,li,mlang1,lj,-mlang2)
    endif
   enddo
  enddo
 enddo

 realgaunt=realgaunt/sqrt(four_pi)

 do ilang=1,l_size
  deallocate (coeff(ilang)%cc)
 enddo

 end function realgaunt

!!***
